@@ -234,7 +234,7 @@ setMethod("connect",signature=signature("report_mig_char"),definition=function(o
 			  " lot_tax_code,", 
 			  " lot_std_code,",
 			  " car_par_code",
-			  " FROM ",get("sch",envir=envir_stacomi),"vue_ope_lot_ech_parqual", 
+			  " FROM ",rlang::env_get(envir_stacomi, "sch"),"vue_ope_lot_ech_parqual", 
 			  " WHERE ope_dic_identifiant in ",vector_to_listsql(r_mig_char@dc@dc_selectionne),
 			  echantillons,
 			  " AND lot_tax_code in ",vector_to_listsql(r_mig_char@taxa@data$tax_code),
@@ -262,7 +262,7 @@ setMethod("connect",signature=signature("report_mig_char"),definition=function(o
 			  " lot_tax_code,", 
 			  " lot_std_code,",
 			  " car_par_code",
-			  " FROM ",get("sch",envir=envir_stacomi),"vue_ope_lot_ech_parquan", 
+			  " FROM ",rlang::env_get(envir_stacomi, "sch"),"vue_ope_lot_ech_parquan", 
 			  " WHERE ope_dic_identifiant in ",vector_to_listsql(r_mig_char@dc@dc_selectionne),
 			  echantillons,
 			  " AND lot_tax_code in ",vector_to_listsql(r_mig_char@taxa@data$tax_code),
